(****************************************************************)
(*  This file summarizes the mappings of Appendix B             *)
(*  from (\nu,n) space to (w,w* ) space                         *)
(*  The notations are:                                          *)  
(*                                                              *)
(*  II = \mathcal{I}                                            *)
(*  See Eq. (4.4)                                               *)
(*                                                              *)
(*  EE = LLA BFKL eigenvalue E_{\nu,n}                          *)
(*  N =  n/(nu^2 + n^2/4)                                       *)
(*  V =  I*nu/(nu^2 + n^2/4)                                    *)
(*  dE[k] = (-I)^k {\partial^k E_{\nu,n}\over \partial\nu^k}    *)
(*  kd[k] = {\delta_{0,n}\over(I nu)^k}                         *)
(*                                                              *)
(*  lp[ws__] = L_ {ws}^+ = 1/2(L_{ws}(z) + L_{ws}(1/z))         *)
(*  lm[ws__] = L_ {ws}^- = 1/2(L_{ws}(z) - L_{ws}(1/z))         *)
(*  See Eq. (3.22)                                              *)
(****************************************************************)


II[kd[0]] = lm[0]

II[1] = 2*lp[1]

II[N] = 4*lm[0, 1]

II[V] = -(lm[0]*lp[1])

II[EE] = -lm[0]^2/4 + lp[1]^2

II[kd[1]] = lm[0]^2/2

II[EE*N] = 2*lm[0, 1]*lp[1]

II[N*V] = -(lm[0]*lm[0, 1])

II[EE*V] = lm[0]^3/6 - 2*lm[0, 1, 1]

II[dE[1]] = -lm[0]^3/12 + 4*lm[0, 1, 1] - lm[0]*lp[1]^2

II[kd[2]] = lm[0]^3/6

II[EE^2] = (2*lp[1]^3)/3 - lp[0, 0, 1]

II[N^2] = -2*lm[0]^2*lp[1] + 12*lp[0, 0, 1]

II[V^2] = (lm[0]^2*lp[1])/2 - lp[0, 0, 1]

II[F4tilde] = -(lm[0]^2*lm[0, 1])/4 + 4*lm[0, 0, 0, 1] - 6*lm[0, 1, 1, 1] + lm[0, 1]*lp[1]^2

II[EE^2*N] = (lm[0]^2*lm[0, 1])/2 - 6*lm[0, 0, 0, 1] + 8*lm[0, 1, 1, 1]

II[N^3] = -6*lm[0]^2*lm[0, 1] + 40*lm[0, 0, 0, 1]

II[N*V^2] = (lm[0]^2*lm[0, 1])/2 - 2*lm[0, 0, 0, 1]

II[EE*N*V] = -2*lp[0, 0, 1, 1]

II[N*dE[1]] = -2*lm[0]*lm[0, 1]*lp[1] + 8*lp[0, 0, 1, 1]

II[EE^2*V] = (lm[0]^3*lp[1])/8 - 2*lm[0, 1, 1]*lp[1] + (lm[0]*lp[1]^3)/6 - lm[0]*Zeta[3]

II[N^2*V] = (lm[0]^3*lp[1])/3 - 2*lm[0]*lp[0, 0, 1]

II[V^3] = -(lm[0]^3*lp[1])/6 + (lm[0]*lp[0, 0, 1])/2

II[EE*dE[1]] = -(lm[0]^3*lp[1])/8 + 2*lm[0, 1, 1]*lp[1] - (lm[0]*lp[1]^3)/2 + (lm[0]*lp[0, 0, 1])/2 + lm[0]*Zeta[3]

II[EE^3] = (7*lm[0]^4)/96 + lm[0, 1]^2/2 - (3*lm[0]*lm[0, 1, 1])/2 + (lm[0]^2*lp[1]^2)/2 + lp[1]^4/2 - (5*lp[1]*lp[0, 0, 1])/2 - 3*lp[1]*Zeta[3]

II[EE*N^2] = lm[0]^4/12 + 2*lm[0, 1]^2 - 2*lm[0]*lm[0, 1, 1] + 2*lp[1]*lp[0, 0, 1] - 4*lp[1]*Zeta[3]

II[EE*V^2] = -lm[0]^4/12 - lm[0, 1]^2/2 + (3*lm[0]*lm[0, 1, 1])/2 - (lm[0]^2*lp[1]^2)/4 + (lp[1]*lp[0, 0, 1])/2 - lp[1]*Zeta[3]

II[V*dE[1]] = lm[0]^4/16 + lm[0, 1]^2 - 2*lm[0]*lm[0, 1, 1] + (3*lm[0]^2*lp[1]^2)/4 - 2*lp[1]*lp[0, 0, 1] + 4*lp[1]*Zeta[3]

II[dE[2]] = -lm[0]^4/24 - 2*lm[0, 1]^2 - (lm[0]^2*lp[1]^2)/2 + 4*lp[1]*lp[0, 0, 1] - 8*lp[1]*Zeta[3]

II[kd[3]] = lm[0]^4/24

II[EE*F4tilde] = (lm[0]^2*lm[0, 1]*lp[1])/8 + (lm[0, 0, 0, 1]*lp[1])/2 - 4*lm[0, 1, 1, 1]*lp[1] + (2*lm[0, 1]*lp[1]^3)/3 + (lm[0, 1]*lp[0, 0, 1])/2 - (lm[0]*lp[0, 0, 1, 1])/2 - 2*lm[0, 1]*Zeta[3]

II[EE^3*N] = (5*lm[0]^2*lm[0, 1]*lp[1])/8 - (15*lm[0, 0, 0, 1]*lp[1])/2 + 12*lm[0, 1, 1, 1]*lp[1] - lm[0, 1]*lp[1]^3 - (lm[0, 1]*lp[0, 0, 1])/2

II[EE*N^3] = -(lm[0]^2*lm[0, 1]*lp[1])/2 + 2*lm[0, 0, 0, 1]*lp[1] + 6*lm[0, 1]*lp[0, 0, 1] - 4*lm[0]*lp[0, 0, 1, 1] - 16*lm[0, 1]*Zeta[3]

II[EE*N*V^2] = -(lm[0]^2*lm[0, 1]*lp[1])/8 + (lm[0, 0, 0, 1]*lp[1])/2 - (lm[0, 1]*lp[0, 0, 1])/2 + lm[0]*lp[0, 0, 1, 1]

II[N*V*dE[1]] = (3*lm[0]^2*lm[0, 1]*lp[1])/4 - 3*lm[0, 0, 0, 1]*lp[1] + lm[0, 1]*lp[0, 0, 1] - 2*lm[0]*lp[0, 0, 1, 1] + 4*lm[0, 1]*Zeta[3]

II[N*dE[2]] = -(lm[0]^2*lm[0, 1]*lp[1]) + 12*lm[0, 0, 0, 1]*lp[1] - 4*lm[0, 1]*lp[0, 0, 1] - 16*lm[0, 1]*Zeta[3]

II[F6atilde] = (lm[0]^3*lm[0, 1])/12 + lm[0, 1]*lm[0, 1, 1] - lm[0]*lm[0, 0, 0, 1] - lp[1]*lp[0, 0, 1, 1]

II[F4tilde*V] = (lm[0]^3*lm[0, 1])/48 - lm[0, 1]*lm[0, 1, 1] - (3*lm[0]*lm[0, 0, 0, 1])/4 + 3*lm[0]*lm[0, 1, 1, 1] - (lm[0]*lm[0, 1]*lp[1]^2)/2 + lp[1]*lp[0, 0, 1, 1]

II[EE^2*N*V] = -(lm[0]^3*lm[0, 1])/48 + (3*lm[0]*lm[0, 0, 0, 1])/4 - 2*lm[0]*lm[0, 1, 1, 1] + (lm[0]*lm[0, 1]*lp[1]^2)/2 - 2*lp[1]*lp[0, 0, 1, 1]

II[N^3*V] = (3*lm[0]^3*lm[0, 1])/4 - 5*lm[0]*lm[0, 0, 0, 1]

II[N*V^3] = (-7*lm[0]^3*lm[0, 1])/48 + (3*lm[0]*lm[0, 0, 0, 1])/4

II[EE*N*dE[1]] = (-5*lm[0]^3*lm[0, 1])/24 + (3*lm[0]*lm[0, 0, 0, 1])/2 - lm[0]*lm[0, 1]*lp[1]^2 + 4*lp[1]*lp[0, 0, 1, 1]

II[F7tilde] = (59*lm[0]^5)/3840 + (5*lm[0]*lm[0, 1]^2)/8 + (lm[0]^2*lm[0, 1, 1])/4 - 10*lm[0, 0, 0, 1, 1] - (7*lm[0, 0, 1, 0, 1])/2 + 7*lm[0, 1, 1, 1, 1] - (11*lm[0]^3*lp[1]^2)/48 - lm[0, 1, 1]*lp[1]^2 + (5*lm[0]*lp[1]^4)/48 + (3*lm[0]*lp[1]*lp[0, 0, 1])/2 - 8*lm[0]*lp[1]*Zeta[3]

II[EE^3*V] = -lm[0]^5/192 + (lm[0]*lm[0, 1]^2)/2 + (3*lm[0]^2*lm[0, 1, 1])/4 - 6*lm[0, 0, 0, 1, 1] - (9*lm[0, 0, 1, 0, 1])/2 - 12*lm[0, 1, 1, 1, 1] + (3*lm[0]^3*lp[1]^2)/16 - (lm[0]*lp[1]*lp[0, 0, 1])/4 + (9*lm[0]*lp[1]*Zeta[3])/2

II[EE*N^2*V] = -lm[0]^5/48 + lm[0]^2*lm[0, 1, 1] - 8*lm[0, 0, 0, 1, 1] - 2*lm[0, 0, 1, 0, 1] - (lm[0]^3*lp[1]^2)/4 + lm[0]*lp[1]*lp[0, 0, 1] - 2*lm[0]*lp[1]*Zeta[3]

II[EE*V^3] = (23*lm[0]^5)/960 - (3*lm[0]^2*lm[0, 1, 1])/4 + 4*lm[0, 0, 0, 1, 1] + (3*lm[0, 0, 1, 0, 1])/2 + (3*lm[0]^3*lp[1]^2)/16 - (3*lm[0]*lp[1]*lp[0, 0, 1])/4 + (3*lm[0]*lp[1]*Zeta[3])/2

II[EE^2*dE[1]] = -lm[0]^5/48 - (lm[0]*lm[0, 1]^2)/2 + 4*lm[0, 0, 0, 1, 1] + 3*lm[0, 0, 1, 0, 1] + 8*lm[0, 1, 1, 1, 1] - (7*lm[0]^3*lp[1]^2)/24 - (lm[0]*lp[1]^4)/6 + lm[0]*lp[1]*lp[0, 0, 1] - 2*lm[0]*lp[1]*Zeta[3]

II[N^2*dE[1]] = lm[0]^5/24 - 2*lm[0]*lm[0, 1]^2 - 4*lm[0]^2*lm[0, 1, 1] + 48*lm[0, 0, 0, 1, 1] + 12*lm[0, 0, 1, 0, 1] + (3*lm[0]^3*lp[1]^2)/2 - 8*lm[0]*lp[1]*lp[0, 0, 1] + 16*lm[0]*lp[1]*Zeta[3]

II[V^2*dE[1]] = -lm[0]^5/480 + (lm[0]*lm[0, 1]^2)/2 + lm[0]^2*lm[0, 1, 1] - 12*lm[0, 0, 0, 1, 1] - 5*lm[0, 0, 1, 0, 1] - (3*lm[0]^3*lp[1]^2)/8 + 2*lm[0]*lp[1]*lp[0, 0, 1] - 4*lm[0]*lp[1]*Zeta[3]

II[V*dE[2]] = -lm[0]^5/15 - 2*lm[0]*lm[0, 1]^2 + 24*lm[0, 0, 0, 1, 1] + 12*lm[0, 0, 1, 0, 1] - 2*lm[0]*lp[1]*lp[0, 0, 1] + 4*lm[0]*lp[1]*Zeta[3]

II[dE[3]] = (7*lm[0]^5)/40 + 6*lm[0]*lm[0, 1]^2 - 48*lm[0, 0, 0, 1, 1] - 24*lm[0, 0, 1, 0, 1] + (lm[0]^3*lp[1]^2)/2

II[kd[4]] = lm[0]^5/120

II[EE^4] = (17*lm[0]^4*lp[1])/96 - 4*lm[0]*lm[0, 1, 1]*lp[1] + lm[0]^2*lp[1]^3 + (2*lp[1]^5)/5 - (5*lm[0]^2*lp[0, 0, 1])/4 - 4*lp[1]^2*lp[0, 0, 1] + (43*lp[0, 0, 0, 0, 1])/4 + 12*lp[0, 0, 1, 1, 1] + 8*lp[0, 1, 0, 1, 1] + 4*lm[0]^2*Zeta[3] - 8*lp[1]^2*Zeta[3]

II[F4tilde*N] = (lm[0]^4*lp[1])/12 - lm[0, 1]^2*lp[1] - lm[0]*lm[0, 1, 1]*lp[1] - (7*lm[0]^2*lp[0, 0, 1])/4 + 15*lp[0, 0, 0, 0, 1] + 12*lp[0, 0, 1, 1, 1] + 8*lp[0, 1, 0, 1, 1] + (7*lm[0]^2*Zeta[3])/2

II[EE^2*N^2] = -(lm[0]^4*lp[1])/24 + 4*lm[0, 1]^2*lp[1] + (lm[0]^2*lp[1]^3)/3 + 3*lm[0]^2*lp[0, 0, 1] - 25*lp[0, 0, 0, 0, 1] - 24*lp[0, 0, 1, 1, 1] - 16*lp[0, 1, 0, 1, 1] - 8*lm[0]^2*Zeta[3]

II[N^4] = (13*lm[0]^4*lp[1])/6 - 20*lm[0]^2*lp[0, 0, 1] + 140*lp[0, 0, 0, 0, 1]

II[EE^2*V^2] = (-13*lm[0]^4*lp[1])/96 - lm[0, 1]^2*lp[1] - (lm[0]^2*lp[1]^3)/12 + (lm[0]^2*lp[0, 0, 1])/4 - lp[0, 0, 0, 0, 1]/4 + 10*lp[0, 0, 1, 1, 1] + 4*lp[0, 1, 0, 1, 1] + 2*lm[0]^2*Zeta[3] - 4*Zeta[5]

II[N^2*V^2] = -(lm[0]^4*lp[1])/8 + lm[0]^2*lp[0, 0, 1] - 5*lp[0, 0, 0, 0, 1]

II[V^4] = (5*lm[0]^4*lp[1])/96 - (lm[0]^2*lp[0, 0, 1])/4 + (3*lp[0, 0, 0, 0, 1])/4

II[EE*V*dE[1]] = (7*lm[0]^4*lp[1])/48 + lm[0, 1]^2*lp[1] + lm[0]*lm[0, 1, 1]*lp[1] - (3*lm[0]^2*lp[0, 0, 1])/4 + (7*lp[0, 0, 0, 0, 1])/2 - 12*lp[0, 0, 1, 1, 1] - 4*lp[0, 1, 0, 1, 1] - (3*lm[0]^2*Zeta[3])/2 + 6*Zeta[5]

II[dE[1]^2] = -(lm[0]^4*lp[1])/3 - 2*lm[0, 1]^2*lp[1] - 8*lm[0]*lm[0, 1, 1]*lp[1] + (3*lm[0]^2*lp[1]^3)/2 + 2*lm[0]^2*lp[0, 0, 1] - 4*lp[1]^2*lp[0, 0, 1] - 9*lp[0, 0, 0, 0, 1] + 48*lp[0, 0, 1, 1, 1] + 16*lp[0, 1, 0, 1, 1] + 2*lm[0]^2*Zeta[3] + 8*lp[1]^2*Zeta[3] - 24*Zeta[5]

II[EE*dE[2]] = (lm[0]^4*lp[1])/6 + 4*lm[0]*lm[0, 1, 1]*lp[1] - lm[0]^2*lp[1]^3 - lm[0]^2*lp[0, 0, 1] + 4*lp[1]^2*lp[0, 0, 1] + 2*lp[0, 0, 0, 0, 1] - 24*lp[0, 0, 1, 1, 1] - 8*lp[0, 1, 0, 1, 1] - 8*lp[1]^2*Zeta[3] + 12*Zeta[5]
